@@ -1,4 +1,4 @@
-from pericaat.intercaatmaster.intercaatWrapper import intercaat
+from intercaatmaster.intercaatWrapper import intercaat
 import sys
 
 
